import 'vfonts/FiraSans.css'

import {
	loadAndSetLocale
} from '@/i18n.js'

import { createRouter, createWebHistory } from 'vue-router'
const HomeView = () => import('../views/Home.vue')
const LogsList = () => import('../views/LogsList.vue')
const LogTemplatesList = () => import('../views/LogTemplatesList.vue')
const CreateLog = () => import('../views/CreateLog.vue')
const CreateLogTemplate = () => import('../views/CreateLogTemplate.vue')
const CameraCapture = () => import('../views/CameraCapture.vue')
const ManagePhotos = () => import('../views/ManagePhotos.vue')
const DevView = () => import('../views/DevView.vue')

const routes = [
	{
		path: '/',
		name: 'Home',
		component: HomeView,
	},
	{
		path: '/logs',
		name: 'LogsList',
		component: LogsList
	},
	{
		path: '/logs/create/:e?',
		name: 'CreateLog',
		component: CreateLog,
		props: (route) => {
			const e = Number.parseInt(route.params.e)
			if (Number.isNaN(e)) {
				return ''
			}
			return {e}
		}
	},
	{
		path: '/templates',
		name: 'LogTemplatesList',
		component: LogTemplatesList
	},
	{
		path: '/templates/create/:e?',
		name: 'CreateLogTemplate',
		component: CreateLogTemplate,
		props: (route) => {
			const e = Number.parseInt(route.params.e)
			if (Number.isNaN(e)) {
				return ''
			}
			return {e}
		}
	},
	{
		path: '/capture',
		name: 'CameraCapture',
		component: CameraCapture
	},
	{
		path: '/photos',
		name: 'ManagePhotos',
		component: ManagePhotos
	},
	{
		path: '/dev',
		name: 'Development',
		component: DevView
	},
]

const router = createRouter({
	history: createWebHistory(),
	routes,
})

// navigation guards
router.beforeEach(async (to, from, next) => {
	const paramsLocale = to.params.locale
	await loadAndSetLocale(paramsLocale)
	next()
})

export default router
